# pyEX-zipline
[pyEX](https://github.com/timkpaine/pyEX) + [Zipline](https://github.com/quantopian/zipline)

[![Build Status](https://travis-ci.org/timkpaine/pyEX-zipline.svg?branch=master)](https://travis-ci.org/timkpaine/pyEX-zipline)
[![Coverage](https://codecov.io/gh/timkpaine/pyEX-zipline/branch/master/graph/badge.svg)](https://codecov.io/gh/timkpaine/pyEX-zipline)
[![BCH compliance](https://bettercodehub.com/edge/badge/timkpaine/pyEX-zipline?branch=master)](https://bettercodehub.com/)
[![License](https://img.shields.io/github/license/timkpaine/pyEX-zipline.svg)](https://pypi.python.org/pypi/pyEX-zipline)
[![PyPI](https://img.shields.io/pypi/v/pyEX-zipline.svg)](https://pypi.python.org/pypi/pyEX-zipline)
[![Docs](https://img.shields.io/readthedocs/pyEX-zipline.svg)](https://pyEX-zipline.readthedocs.io)

# Example
![](https://raw.githubusercontent.com/timkpaine/pyEX-zipline/master/docs/example.png)

